PCB Environment: NavPixel< chan_t > Struct Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
NavPixel< chan_t > Struct Template Reference

`#include <NavImage.hpp>`

## Public Member Functions
void | setFloat (const NavPixel< float > &, float coverage)
void | addPoint (const NavPoint &, char z, chan_t vTB, chan_t vM)
void | addPin (char z, chan_t)
void | addRatsNest (char z, chan_t)
void | addTrack (char z, chan_t vTB, chan_t vM)
void | addVia (chan_t)
void | zero ()
bool | isNonzero () const

## Data Fields
chan_t | Chan [NAV_IMAGE_NUM_CHANS]

## Detailed Description

template<typename chan_t>
struct NavPixel< chan_t >

This class represents a "pixel" in an "image" representation of the board. If the encoding is u8, by default we use 0 to 144 for channels with graduation (PIN_T,B and TRACK_M), and and 0/1 otherwise. 144 is the most divisble by the common number of layers (2,3,4,6,8,9,12,16). This avoid roundoff errors when converting to floats for neural networks.

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavImage.hpp